@@ -1,7 +1,6 @@
-#!/usr/bin/env perl
+#!perl
 use strict;
 use warnings;
-
 use Math::Fractal::Julia;
 use Imager;
 
@@ -21,11 +20,12 @@ $palette[0] = [ 255, 255, 255 ];
 
 my $img = Imager->new( xsize => $width, ysize => $height );
 
-foreach my $y ( 0 .. $height - 1 ) {
-    foreach my $x ( 0 .. $width - 1 ) {
+for my $y ( 0 .. $height - 1 ) {
+    for my $x ( 0 .. $width - 1 ) {
         my $iter = $julia->point( $x, $height - $y - 1 );
         $img->setpixel( x => $x, y => $y, color => $palette[$iter] );
     }
 }
 
 $img->write( file => 'julia.png' );
+
